print

Function print 

pub fn print(args: &[Value]) -> Result<Value, FuncError>
An implementation of golang’s fmt.Sprint

Golang’s Sprint formats using the default formats for its operands and returns the resulting string. Spaces are added between operands when neither is a string.

Example

use gtmpl::template;
let equal = template(r#"{{ print "Hello " . "!" }}"#, "world");
assert_eq!(&equal.unwrap(), "Hello world!");